==> ejc-sealm-impl-3.0.0-20220114.061249-33-sources.jar: com/ejianc/business/sealm/bean/YzdjEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 印章登记
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yzdj")
public class YzdjEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bzdw_id")
    private Long bzdwId; // 编制单位id
    @TableField(value="bzdw_name")
    private String bzdwName; // 编制单位名称
    @TableField(value="yzsq_id")
    private Long yzsqId; // 印章申请id
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private String yylxName; // 用印类型名称
    @TableField(value="kzzy")
    private String kzzy; // 刻章字样
    @TableField(value="ssdw_id")
    private Long ssdwId; // 所属单位id
    @TableField(value="ssdw_name")
    private String ssdwName; // 所属单位名称
    @TableField(value="dqbgr_id")
    private Long dqbgrId; // 当前保管人id
    @TableField(value="dqbgr_name")
    private String dqbgrName; // 当前保管人名称
    @TableField(value="kzsj_time")
    private java.util.Date kzsjTime; // 刻制时间
    @TableField(value="baqk")
    private Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @TableField(value="basj_time")
    private java.util.Date basjTime; // 备案时间
    @TableField(value="badw_id")
    private Long badwId; // 备案单位id
    @TableField(value="badw_name")
    private String badwName; // 备案单位名称
    @TableField(value="scdw_id")
    private Long scdwId; // 生产单位id
    @TableField(value="scdw_name")
    private String scdwName; // 生产单位名称
    @TableField(value="zt")
    private Integer zt; // 状态，默认0总部在库。1正常发放2外借待归3已销毁5异常
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="sf_yzsq")
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    @TableField(value="begin_date")
    private java.util.Date beginDate; // 开始日期
    @TableField(value="end_date")
    private java.util.Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="yzbh")
    private String yzbh; // 印章编号
    @TableField(value="kzzyjc")
    private String kzzyjc; // 刻章字样简称
    @TableField(value="gldw_id")
    private java.lang.Long gldwId; // 管理单位id
    @TableField(value="gldw_name")
    private java.lang.String gldwName; // 管理单位名称
    
    

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 编制单位id
     */
    public Long getBzdwId() {
        return bzdwId;
    }

    /**
     * 编制单位id
     */
    public void setBzdwId(Long bzdwId) {
        this.bzdwId = bzdwId;
    }
    /**
     * 编制单位名称
     */
    public String getBzdwName() {
        return bzdwName;
    }

    /**
     * 编制单位名称
     */
    public void setBzdwName(String bzdwName) {
        this.bzdwName = bzdwName;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    public Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    public void setDqbgrId(Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁5异常
     */
    public Integer getZt() {
        return zt;
    }

    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁5异常
     */
    public void setZt(Integer zt) {
        this.zt = zt;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    /**
     * 印章编号
     */
    public String getYzbh() {
        return yzbh;
    }

    /**
     * 印章编号
     */
    public void setYzbh(String yzbh) {
        this.yzbh = yzbh;
    }
    /**
     * 刻章字样简称
     */
    public String getKzzyjc() {
        return kzzyjc;
    }

    /**
     * 刻章字样简称
     */
    public void setKzzyjc(String kzzyjc) {
        this.kzzyjc = kzzyjc;
    }
    /**
     * 管理单位id
     */
    public java.lang.Long getGldwId() {
        return gldwId;
    }

    /**
     * 管理单位id
     */
    public void setGldwId(java.lang.Long gldwId) {
        this.gldwId = gldwId;
    }
    /**
     * 管理单位名称
     */
    public java.lang.String getGldwName() {
        return gldwName;
    }

    /**
     * 管理单位名称
     */
    public void setGldwName(java.lang.String gldwName) {
        this.gldwName = gldwName;
    }
}

==> ejc-sealm-impl-3.0.0-20220309.001629-53-sources.jar: com/ejianc/business/sealm/bean/YzdjEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 印章登记
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yzdj")
public class YzdjEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bzdw_id")
    private Long bzdwId; // 编制单位id
    @TableField(value="bzdw_name")
    private String bzdwName; // 编制单位名称
    @TableField(value="yzsq_id")
    private Long yzsqId; // 印章申请id
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private String yylxName; // 用印类型名称
    @TableField(value="kzzy")
    private String kzzy; // 刻章字样
    @TableField(value="ssdw_id")
    private Long ssdwId; // 所属单位id
    @TableField(value="ssdw_name")
    private String ssdwName; // 所属单位名称
    @TableField(value="dqbgr_id")
    private Long dqbgrId; // 当前保管人id
    @TableField(value="dqbgr_name")
    private String dqbgrName; // 当前保管人名称
    @TableField(value="kzsj_time")
    private java.util.Date kzsjTime; // 刻制时间
    @TableField(value="baqk")
    private Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @TableField(value="basj_time")
    private java.util.Date basjTime; // 备案时间
    @TableField(value="badw_id")
    private Long badwId; // 备案单位id
    @TableField(value="badw_name")
    private String badwName; // 备案单位名称
    @TableField(value="scdw_id")
    private Long scdwId; // 生产单位id
    @TableField(value="scdw_name")
    private String scdwName; // 生产单位名称
    @TableField(value="zt")
    private Integer zt; // 状态，默认0总部在库。1正常发放2外借待归3已销毁5异常
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="sf_yzsq")
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    @TableField(value="begin_date")
    private java.util.Date beginDate; // 开始日期
    @TableField(value="end_date")
    private java.util.Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="yzbh")
    private String yzbh; // 印章编号
    @TableField(value="kzzyjc")
    private String kzzyjc; // 刻章字样简称
    @TableField(value="gldw_id")
    private java.lang.Long gldwId; // 管理单位id
    @TableField(value="gldw_name")
    private java.lang.String gldwName; // 管理单位名称
    @TableField(value="message_from")
    private Integer messageFrom; // 数据来源：0投标报名，1资格评审，2投标文件评审
    @TableField(value="bid_id")
    private Long bidId; // 投标模块id
    @TableField(value="bid_code")
    private String bidCode; // 投标的单据编码
    
    

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 编制单位id
     */
    public Long getBzdwId() {
        return bzdwId;
    }

    /**
     * 编制单位id
     */
    public void setBzdwId(Long bzdwId) {
        this.bzdwId = bzdwId;
    }
    /**
     * 编制单位名称
     */
    public String getBzdwName() {
        return bzdwName;
    }

    /**
     * 编制单位名称
     */
    public void setBzdwName(String bzdwName) {
        this.bzdwName = bzdwName;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    public Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    public void setDqbgrId(Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁5异常
     */
    public Integer getZt() {
        return zt;
    }

    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁5异常
     */
    public void setZt(Integer zt) {
        this.zt = zt;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    /**
     * 印章编号
     */
    public String getYzbh() {
        return yzbh;
    }

    /**
     * 印章编号
     */
    public void setYzbh(String yzbh) {
        this.yzbh = yzbh;
    }
    /**
     * 刻章字样简称
     */
    public String getKzzyjc() {
        return kzzyjc;
    }

    /**
     * 刻章字样简称
     */
    public void setKzzyjc(String kzzyjc) {
        this.kzzyjc = kzzyjc;
    }
    /**
     * 管理单位id
     */
    public java.lang.Long getGldwId() {
        return gldwId;
    }

    /**
     * 管理单位id
     */
    public void setGldwId(java.lang.Long gldwId) {
        this.gldwId = gldwId;
    }
    /**
     * 管理单位名称
     */
    public java.lang.String getGldwName() {
        return gldwName;
    }

    /**
     * 管理单位名称
     */
    public void setGldwName(java.lang.String gldwName) {
        this.gldwName = gldwName;
    }

    public Integer getMessageFrom() {
        return messageFrom;
    }

    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    public Long getBidId() {
        return bidId;
    }

    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }
    public String getBidCode() {
        return bidCode;
    }

    public void setBidCode(String bidCode) {
        this.bidCode = bidCode;
    }
}
